@@ -1,5 +1,5 @@
 package WebAPI::DBIC;
-$WebAPI::DBIC::VERSION = '0.002007';
+$WebAPI::DBIC::VERSION = '0.003002';
 use strict; # keep our kwalitee up!
 use warnings;
 1;
@@ -16,7 +16,7 @@ WebAPI::DBIC
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 DESCRIPTION
 
@@ -36,7 +36,7 @@ L<Path::Router> as the router. (Other routers could be supported.)
 
 * Rich support for multiple hypermedia types, including JSON API
 (application/vnd.api+json) and HAL (application/hal+json).
-The Collection+JSON hypermedia type could be added in future.
+The Collection+JSON and JSON-LD hypermedia types could be added in future.
 
 * Automatic detection and exposure of result set relationships.
 
@@ -45,8 +45,8 @@ The Collection+JSON hypermedia type could be added in future.
 * An example .psgi file that gives you an instant web service for any
 DBIx::Class schema.
 
-* Includes a built-in copy of the generic HAL API browser application so you
-can be browsing your new API in mimutes.
+* Includes a generic HAL API browser application so you can be browsing your
+new API in minutes.
 
 =head2 HAL - Hypertext Application Language
 
@@ -104,7 +104,7 @@ Main TO-DOs in approximate order of likely implementation:
 
 The L<Web::Machine> module provides a RESTful web framework modeled as a formal
 state machine. This is a rigorous and powerful approach, originally developed
-in Haskel and since ported to many other languages.
+in Erlang and since ported to many other languages.
 
 See L<https://raw.githubusercontent.com/basho/webmachine/develop/docs/http-headers-status-v3.png>
 for an image of the state machine.
@@ -145,9 +145,8 @@ WebAPI::DBIC - A composable RESTful JSON API to DBIx::Class schemas using roles
 
 The WebAPI::DBIC code has been in production use since early 2013, however it's
 only recently been open sourced (July 2014) so it's still lacking in documentation.
-
-It's also undergoing a period of refactoring and enhancement now there are more
-developers contributing and the code is being applied to more domains.
+It's also undergoing a period of refactoring, enhancement and evolution now
+there are more developers contributing and the code is being applied to more domains.
 
 Interested? Please get involved! See L</HOW TO GET HELP> below.
 
@@ -374,10 +373,7 @@ simply with L<Catalyst::Action::FromPSGI>.  Here's an example integration:
 
    WebAPI::DBIC::WebApp->new({
      schema   => $c->model('DB')->schema,
-     writable => 0,            # set true if desired
-     http_auth_type => 'none', # will use Catalysts' auth for the given path
-                               # consider leveraging chaining or another
-                               # ActionRole for auth
+     ...
    })->to_psgi_app
  }
 
@@ -973,7 +969,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
