@@ -1,8 +1,8 @@
 package WebAPI::DBIC::Resource::GenericCore;
-$WebAPI::DBIC::Resource::GenericCore::VERSION = '0.002007';
+$WebAPI::DBIC::Resource::GenericCore::VERSION = '0.003002';
 
 use Moo;
-use namespace::clean;
+use MooX::StrictConstructor;
 
 extends 'WebAPI::DBIC::Resource::Base';
 with    'WebAPI::DBIC::Role::JsonEncoder',
@@ -30,7 +30,7 @@ WebAPI::DBIC::Resource::GenericCore
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 NAME
 
@@ -42,7 +42,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
