@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::DBIC;
-$WebAPI::DBIC::Resource::Role::DBIC::VERSION = '0.002007';
+$WebAPI::DBIC::Resource::Role::DBIC::VERSION = '0.003002';
 
 use Carp qw(croak confess);
 use Devel::Dwarn;
@@ -21,9 +21,6 @@ has set => (
    required => 1,
 );
 
-has writable => (
-   is => 'ro',
-);
 
 has prefetch => (
     is => 'rw',
@@ -75,7 +72,6 @@ sub web_machine_resource {
         throwable => $self->throwable,
         prefetch  => [], # don't propagate prefetch by default
         set => undef,
-        id => undef,
         #  XXX others? which and why? generalize
         %resource_args
     );
@@ -154,7 +150,7 @@ WebAPI::DBIC::Resource::Role::DBIC
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 NAME
 
@@ -166,7 +162,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
