@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::DBICAuth;
-$WebAPI::DBIC::Resource::Role::DBICAuth::VERSION = '0.002007';
+$WebAPI::DBIC::Resource::Role::DBICAuth::VERSION = '0.003002';
 
 use Carp qw(confess);
 use Try::Tiny;
@@ -47,28 +47,33 @@ sub is_authorized {
     my ($self, $auth_header) = @_;
 
     my $http_auth_type = $self->http_auth_type || '';
-    if ($http_auth_type =~ /^none/i) {
+    if ($http_auth_type =~ /^(none|disabled)$/) {
         # This role was included in the resource, so auth was desired, yet auth
-        # has been disabled. That seems worthy of a warning.
-        my $name = $self->set->result_source->result_class; # XXX the path would be better
-        warn "HTTP authentication configured but disabled for $name\n"
-            unless our $warn_once->{"http_auth_type $name"}++;
+        # has been specified. That seems worthy of a warning.
+        # 'none' gives a warning, but 'disabled' is silent.
+        (my $name = $self->request->path) =~ s:/\d+$::;
+        warn "HTTP authentication configured but not enabled for $name\n"
+            if $http_auth_type ne 'disabled'
+            and not our $warn_once->{"http_auth_type $name"}++;
         return 1
     }
-    elsif ($http_auth_type =~ /^basic/i) {
+    elsif ($http_auth_type eq 'Basic') {
 
-        my $auth_realm = $self->set->result_source->schema->storage->connect_info->[0]->{dsn} # dsn
-            or die "panic: no dsn set";
+        # https://metacpan.org/pod/DBIx::Class::Storage::DBI#connect_info
+        my $ci = $self->set->result_source->schema->storage->connect_info;
+        # extract the dsn (doesn't handle $ci->[0] being a code ref)
+        my $dsn = (ref $ci->[0]) ? $ci->[0]->{dsn} : $ci->[0];
+        confess "Can't determine DSN to use as auth realm from @$ci"
+            if !$dsn or ref $dsn;
 
+        my $auth_realm = "Insecure unless https! - $dsn"; # XXX get via a method
         if ( $auth_header ) {
             return 1 if $self->connect_schema_as($auth_header->username, $auth_header->password);
         }
         return create_header( 'WWWAuthenticate' => [ 'Basic' => ( realm => $auth_realm ) ] );
     }
-    else {
-        die "Unsupported value for http_auth_type: $http_auth_type";
-    }
 
+    die "Unsupported value for http_auth_type: $http_auth_type";
 }
 
 
@@ -86,7 +91,7 @@ WebAPI::DBIC::Resource::Role::DBICAuth
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 NAME
 
@@ -98,7 +103,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
