@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::Item;
-$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.002007';
+$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.003002';
 
 use Moo::Role;
 
@@ -13,9 +13,16 @@ requires 'set';
 has id => (         # array of 1 or more key values from url path
    is => 'ro',
    #isa => array ref
-   required => 1,
+   lazy => 1,
+   builder => '_build_id'
 );
 
+sub _build_id {
+    # we could possibly try to extract an id from item() if that's set
+    # (but we'd need to avoid infinite recursion)
+    die sprintf "No id provided for %s", ref shift;
+}
+
 has item => (
    is => 'rw', # XXX
    lazy => 1,
@@ -56,7 +63,7 @@ WebAPI::DBIC::Resource::Role::Item
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 DESCRIPTION
 
@@ -75,7 +82,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
