@@ -1,7 +1,8 @@
 package WebAPI::DBIC::Route;
-$WebAPI::DBIC::Route::VERSION = '0.002007';
+$WebAPI::DBIC::Route::VERSION = '0.003002';
 
 use Moo;
+use MooX::StrictConstructor;
 
 use Module::Runtime qw(use_module);
 
@@ -101,8 +102,10 @@ sub as_add_route_args {
         # perform any required setup for this request & params in @_
         $resource_args_from_route->($request, \%resource_args_from_params, @_);
 
-        warn sprintf "%s: running %s machine (@{[ keys %resource_args_from_params ]})\n",
-                $self->path, $resource_class
+        warn sprintf "/%s: running %s machine (extra args: %s; default args: %s)\n",
+                $self->path, $resource_class,
+                join(",", sort keys %resource_args_from_params),
+                join(",", sort keys %{$self->resource_args})
             if $ENV{WEBAPI_DBIC_DEBUG};
 
         my $app = Web::Machine->new(
@@ -141,7 +144,7 @@ WebAPI::DBIC::Route
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 DESCRIPTION
 
@@ -155,7 +158,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
