@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Router;
-$WebAPI::DBIC::Router::VERSION = '0.002007';
+$WebAPI::DBIC::Router::VERSION = '0.003002';
 
 use Moo;
 
@@ -8,10 +8,14 @@ use Carp qw(croak);
 use Path::Router;
 use Plack::App::Path::Router;
 
+use namespace::clean -except => [qw(meta)];
+use MooX::StrictConstructor;
+
 
 has router => (
     is => 'ro',
     default => sub { Path::Router->new },
+    handles => [ qw(match) ],
 );
 
 
@@ -39,6 +43,7 @@ sub to_psgi_app {
 
 
 sub uri_for { # called by WebAPI::DBIC::Resource::Role::Router
+    local $SIG{__DIE__}; # https://github.com/timbunce/WebAPI-DBIC/issues/22
     return shift->router->uri_for(@_);
 }
 
@@ -57,7 +62,7 @@ WebAPI::DBIC::Router
 
 =head1 VERSION
 
-version 0.002007
+version 0.003002
 
 =head1 DESCRIPTION
 
@@ -75,7 +80,7 @@ Tim Bunce <Tim.Bunce@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Tim Bunce.
+This software is copyright (c) 2015 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
